@@ -1,11 +1,7 @@
 from __future__ import division
 import sys
-from mofapy2.core.nodes.variational_nodes import *
-from mofapy2.core.nodes.Kc_node import Kc_Node
-from mofapy2.core.nodes.Kg_node import Kg_Node
-from mofapy2.core.gp_utils import *
 import scipy as s
-from mofapy2.core import gpu_utils
+import numpy as np
 import pandas as pd
 # from fastdtw import fastdtw
 import copy
@@ -14,6 +10,11 @@ import copy
 # from mofapy2.core.distributions.multi_task_GP import MultitaskGPModel, ELBO, myMultitaskGaussianLikelihood
 # from gpytorch.likelihoods import MultitaskGaussianLikelihood
 import mofapy2.core.gp_utils as gp_utils
+from mofapy2.core.nodes.variational_nodes import *
+from mofapy2.core.nodes.Kc_node import Kc_Node
+from mofapy2.core.nodes.Kg_node import Kg_Node
+from mofapy2.core.gp_utils import *
+from mofapy2.core import gpu_utils
 
 
 # TODO:
@@ -73,24 +74,6 @@ class Sigma_Node_base(Node):
         self.model_groups = model_groups
         self.groupsidx = pd.factorize(self.group_labels)[0]         # for each sample gives the idx in groups
         self.groups = np.unique(self.group_labels)                  # distinct group labels
-        if self.model_groups:
-            self.G = len(self.groups)  # number of groups
-            if rankx is None:
-                rankx = 1
-                # if self.G < 50:
-                #     rankx = 1
-                # else:
-                #     rankx = 2
-            self.kronecker = np.all([np.all(self.sample_cov_transformed[self.groupsidx == 0] ==
-                                             self.sample_cov_transformed[self.groupsidx == g]) for g in
-                                             range(self.G)])
-            self.initKg(rank = rankx, spectral_decomp = self.kronecker)
-        else:
-            # all samples are modelled jointly in the covariate kernel
-            self.Kg = None
-            self.kronecker = True
-            self.G = 1
-
 
     def initKc(self, transformed_sample_cov, cov4grid=None, spectral_decomp=True):
         """
@@ -567,6 +550,21 @@ class Sigma_Node(Sigma_Node_base):
 
         super().__init__(dim, sample_cov, groups, start_opt, opt_freq, n_grid, rankx, model_groups)
 
+        # initialize group kernel
+        if self.model_groups:
+            self.G = len(self.groups)  # number of groups
+            if rankx is None:
+                rankx = 1
+            self.kronecker = np.all([np.all(self.sample_cov_transformed[self.groupsidx == 0] ==
+                                             self.sample_cov_transformed[self.groupsidx == g]) for g in
+                                             range(self.G)])
+            self.initKg(rank = rankx, spectral_decomp = self.kronecker)
+        else:
+            # all samples are modelled jointly in the covariate kernel
+            self.Kg = None
+            self.kronecker = True
+            self.G = 1
+
         # initialize Sigma terms (unstructured)
         self.Nu = self.N                                            # dimension of the inverse matrix (can differ for sparse subclasses)
         self.Sigma_inv = np.zeros([self.K, self.Nu, self.Nu])
@@ -580,6 +578,7 @@ class Sigma_Node(Sigma_Node_base):
         self.initKc(self.sample_cov_transformed, spectral_decomp=self.kronecker)
 
 
+
 class Sigma_Node_sparse(Sigma_Node_base):
     """
         Sigma node making use of sparse inference.
@@ -592,13 +591,29 @@ class Sigma_Node_sparse(Sigma_Node_base):
                  n_grid=10, rankx = None, model_groups = False, idx_inducing = None):
 
         super().__init__(dim, sample_cov, groups, start_opt, opt_freq, n_grid, rankx, model_groups)
-        self.kronecker = False
 
         # sparse GPs
         self.idx_inducing = idx_inducing
         self.Nu = len(idx_inducing)
+        self.groupsidx_all = self.groupsidx
         self.groupsidx = self.groupsidx[self.idx_inducing]                  # subset to group labels for inducing points
 
+        # initialize group kernel
+        if self.model_groups:
+            self.G = len(self.groups)  # number of groups
+            if rankx is None:
+                rankx = 1
+            self.kronecker = np.all([np.all(self.sample_cov_transformed[self.idx_inducing][self.groupsidx == 0] ==
+                                             self.sample_cov_transformed[self.idx_inducing][self.groupsidx == g]) for g in
+                                             range(self.G)])
+            self.initKg(rank = rankx, spectral_decomp = self.kronecker)
+        else:
+            # all samples are modelled jointly in the covariate kernel
+            self.Kg = None
+            self.kronecker = True
+            self.G = 1
+
+
         # initialize Sigma terms (unstructured)
         self.Sigma_inv = np.zeros([self.K, self.Nu, self.Nu])
         self.Sigma = np.zeros([self.K, self.N, self.N])
@@ -633,6 +648,7 @@ class Sigma_Node_sparse(Sigma_Node_base):
 
             else:
                     self.update_Sigma_complete_k(k)
+                    # TODO make use of Kronecker structures where possible in the following
                     self.Sigma_inv[k, :, :] = np.linalg.inv(self.Sigma[k, self.idx_inducing, :][:,self.idx_inducing])
                     self.Sigma_inv_logdet[k] = np.linalg.slogdet(self.Sigma_inv[k, :, :])[1]
 
@@ -646,7 +662,12 @@ class Sigma_Node_sparse(Sigma_Node_base):
                 self.Sigma[k, :, :] = np.eye(self.N)
         else:
             Kc_k = self.Kc.eval_at_newpoints_k(self.sample_cov_transformed, k)
-            self.Sigma[k, :, :] = (1 - self.zeta[k]) * Kc_k  + self.zeta[k] * np.eye(self.N)
+            if not self.model_groups:
+                self.Sigma[k, :, :] = (1 - self.zeta[k]) * Kc_k  + self.zeta[k] * np.eye(self.N)
+            else:
+                self.Sigma[k, :, :] = (1 - self.zeta[k]) *\
+                                      Kc_k * self.Kg.Kmat[k, self.groupsidx_all, :][:, self.groupsidx_all] + \
+                                      self.zeta[k] * np.eye(self.N)
 
     def updateParameters(self, ix, ro):
         """
@@ -674,21 +695,32 @@ class Sigma_Node_warping(Sigma_Node_base):
     def __init__(self, dim, sample_cov, groups, start_opt=20, opt_freq = 10,
                  n_grid=10, rankx = None, model_groups = False,
                  warping_freq = 20, warping_ref = 0, warping_open_begin = True,
-                 warping_open_end = True):
+                 warping_open_end = True, warping_groups = None):
 
         super().__init__(dim, sample_cov, groups, start_opt, opt_freq, n_grid, rankx, model_groups)
-
         self.kronecker = False
         self.new_alignment = False
 
+        # initialize group kernel
+        if self.model_groups:
+            self.G = len(self.groups)  # number of groups
+            if rankx is None:
+                rankx = 1
+            self.initKg(rank = rankx, spectral_decomp = self.kronecker)
+        else:
+            # all samples are modelled jointly in the covariate kernel
+            self.Kg = None
+            self.G = 1
+
         # set warping options
-        self.G4warping = len(self.groups) # number of groups to consider for warping (if no group kernel this differs from self.G)
+        self.G4warping =  len(pd.factorize(warping_groups)[1]) # number of groups to consider for warping (if no group kernel this differs from self.G)
         assert warping_ref < self.G4warping,\
             "Reference group not correctly specified, exceeds the number of groups."
         self.reference_group = warping_ref
         self.warping_freq = warping_freq
         self.warping_open_begin = warping_open_begin
         self.warping_open_end = warping_open_end
+        self.warping_groups = pd.factorize(warping_groups)[0]
 
         assert self.start_opt % self.warping_freq == 0,\
             "start_opt should be a multiple of warping_freq"            # to ensure in the first opt. step alignment is performed
@@ -722,9 +754,13 @@ class Sigma_Node_warping(Sigma_Node_base):
             self.optimise(var)
 
             # after a new alignment check that a sufficient smoothness and sharedness is present for a sensible alignment
-            if self.new_alignment and (all(1-self.get_zeta() < 0.3) or all(self.get_sharedness()< 0.3)):
-                print("WARNING: Factors show little shared smooth variation between groups - alignment might not work as intended.")
-                #self.sample_cov_transformed = copy.copy(self.sample_cov)
+            if self.new_alignment:
+                if self.model_groups:
+                    if (all(1-self.get_zeta() < 0.1) or all(self.get_sharedness()< 0.1)):
+                        print("WARNING: Factors show little shared smooth variation between groups - alignment might not work as intended.")
+                else:
+                    if all(1 - self.get_zeta() < 0.1):
+                        print("WARNING: Factors show little smooth variation - alignment might not work as intended.")
                 self.new_alignment = False
 
 
@@ -741,18 +777,34 @@ class Sigma_Node_warping(Sigma_Node_base):
         paths = []
         for g in range(self.G4warping):
             if g is not self.reference_group:
-                # reorder by covariate value to ensure monotonicity constrains are correctly placed
-                idx_ref_order = np.argsort(self.sample_cov[self.groupsidx == self.reference_group,0])
-                idx_query_order = np.argsort(self.sample_cov[self.groupsidx == g,0])
-                # allow for partial matching (no corresponding end and beginning)
-                step_pattern = "asymmetric" if self.warping_open_begin or self.warping_open_end else "symmetric2"
-                alignment = dtw(Z[self.groupsidx == g, :][idx_query_order,:], Z[self.groupsidx == self.reference_group, :][idx_ref_order,:],
-                                open_begin = self.warping_open_begin, open_end = self.warping_open_end, step_pattern=step_pattern)
-                query_idx = alignment.index1 # dtw-python
+                tg = np.sort(np.unique(self.sample_cov[self.warping_groups == g,0]))
+                Zg = [np.mean(Z[self.warping_groups == g, :][self.sample_cov[self.warping_groups == g,0] == t,:], axis =0) for t in tg]
+                tref = np.sort(np.unique(self.sample_cov[self.warping_groups == self.reference_group,0]))
+                Zref= [np.mean(Z[self.warping_groups == self.reference_group, :][self.sample_cov[self.warping_groups == self.reference_group,0] == t,:], axis =0) for t in tref]
+                step_pattern = "asymmetric" # matches each element in the query to exactly one in the reference
+                # step_pattern = "asymmetric" if self.warping_open_begin or self.warping_open_end else "symmetric2"
+                alignment = dtw(np.array(Zg),
+                                np.array(Zref),
+                                open_begin=self.warping_open_begin, open_end=self.warping_open_end,
+                                step_pattern=step_pattern)
                 ref_idx = alignment.index2
-                ref_val = self.sample_cov[self.groupsidx == self.reference_group, 0][idx_ref_order][ref_idx]
-                idx = np.where(self.groupsidx == g)[0][idx_query_order][query_idx]
-                self.sample_cov_transformed[idx, 0] = ref_val
+                new_val = tref[ref_idx]
+                old_val = self.sample_cov[self.warping_groups == g, 0]
+                new_sample_cov = [new_val[tg == told].item() for told in old_val]
+                self.sample_cov_transformed[self.warping_groups == g, 0] = new_sample_cov
+
+                # # reorder by covariate value to ensure monotonicity constrains are correctly placed
+                # idx_ref_order = np.argsort(self.sample_cov[self.warping_groups == self.reference_group,0])
+                # idx_query_order = np.argsort(self.sample_cov[self.warping_groups == g,0])
+                # # allow for partial matching (no corresponding end and beginning)
+                # step_pattern = "asymmetric" if self.warping_open_begin or self.warping_open_end else "symmetric2"
+                # alignment = dtw(Z[self.warping_groups == g, :][idx_query_order,:], Z[self.warping_groups == self.reference_group, :][idx_ref_order,:],
+                #                 open_begin = self.warping_open_begin, open_end = self.warping_open_end, step_pattern=step_pattern)
+                # query_idx = alignment.index1 # dtw-python
+                # ref_idx = alignment.index2
+                # ref_val = self.sample_cov[self.warping_groups == self.reference_group, 0][idx_ref_order][ref_idx]
+                # idx = np.where(self.warping_groups == g)[0][idx_query_order][query_idx]
+                # self.sample_cov_transformed[idx, 0] = ref_val
 
         # covariate kernel needs to be re-initialized after each warping
         self.initKc(self.sample_cov_transformed, spectral_decomp=self.kronecker)
