@@ -747,7 +747,7 @@ class entry_point(object):
         if seed is None:  # Seed for the random number generator
             seed = int(round(time()*1000)%1e6)
         self.train_opts['seed'] = int(seed)
-        # s.random.seed(self.train_opts['seed'])
+        # np.random.seed(self.train_opts['seed'])
 
         # Weight the views to avoid imbalance problems?
         self.train_opts['weight_views'] = weight_views
@@ -791,7 +791,7 @@ class entry_point(object):
 
     def set_smooth_options(self, scale_cov = False, start_opt=20, n_grid=20, opt_freq=10, model_groups = True,
         warping = False, warping_freq = 20, warping_ref = 0, warping_open_begin = True, warping_open_end = True,
-        sparseGP = False, frac_inducing = None):
+        sparseGP = False, frac_inducing = None, warping_groups = None):
 
         """ 
         Method to activate and set options for a functional MOFA model (MEFISTO).
@@ -853,6 +853,11 @@ class entry_point(object):
         self.smooth_opts['warping_ref'] = int(warping_ref)
         self.smooth_opts['warping_open_begin'] = bool(warping_open_begin)
         self.smooth_opts['warping_open_end'] = bool(warping_open_end)
+        if warping_groups is None:
+            self.smooth_opts['warping_groups'] = self.data_opts['samples_groups']
+        else:
+            self.smooth_opts['warping_groups'] = np.array(warping_groups)
+
         if self.smooth_opts['warping'] is True:
             assert self.dimensionalities["G"] > 1, "The warping functionality is only relevant when having multi-group data"
             assert self.dimensionalities["C"] == 1, "Warping only implemented for one dimensional covariates"
@@ -868,6 +873,8 @@ class entry_point(object):
        # Sparse GPs
         if sparseGP is True:
             assert not self.smooth_opts['warping'], "The warping functionality cannot be used in conjunction with the sparseGP option."
+            assert np.all([l == 'gaussian' for l in self.model_opts['likelihoods']]), "Non-gaussian likelihoods cannot be used in conjunction with the sparseGP option."
+
             self.smooth_opts['sparseGP'] = True
             if self.dimensionalities["N"] < 1000:
                 print("Warning: sparseGP should only be used when having a large sample size (>1e3)\n")
@@ -1044,8 +1051,10 @@ class entry_point(object):
         if new_covariates is None:
             new_covariates = self.sample_cov
 
+        new_covariates = np.unique(new_covariates, axis =0)
+
         # get group-covariate combinations included in the model
-        old_groups = self.model.nodes['Sigma'].groupsidx
+        old_groups = pd.factorize(self.model.nodes['Sigma'].group_labels)[0]
         old_covariates = self.model.nodes['Sigma'].sample_cov_transformed
         all_covariates = np.unique(np.vstack([new_covariates, old_covariates]), axis =0)
         N = all_covariates.shape[0]
@@ -1057,13 +1066,7 @@ class entry_point(object):
 
         Sigma_terms = self.model.nodes['Sigma'].getExpectations()
         Sigma = Sigma_terms['cov']
-        if not self.smooth_opts['sparseGP']:
-            Sigma_inv = Sigma_terms['inv']
-        else:
-            N = Z.shape[0]
-            Sigma_inv = np.zeros([K, N, N])
-            for k in range(K):
-                Sigma_inv[k,:,:] = np.linalg.inv(Sigma[k,:,:])
+        Sigma_inv = Sigma_terms['inv']
                 
         GP_param = self.model.nodes['Sigma'].getParameters()
         if groups == "all":
@@ -1090,22 +1093,43 @@ class entry_point(object):
         for k in range(K):
             Kc_new = self.model.nodes['Sigma'].Kc.eval_at_newpoints_k(all_covariates,k)
             K_new_k = GP_param['scale'][k] * np.kron(Kg[k,:,:], Kc_new)
-            Sigma_new_k = K_new_k + (1 - GP_param['scale'][k]) * np.eye(N * G)
-            Z_new_mean[:,k] = gpu_utils.dot(K_new_k[newidx, :][:, oldix], gpu_utils.dot(Sigma_inv[k,:,:], Z[:,k]))
+            Sigma_new_k = K_new_k + (1 - GP_param['scale'][k]) * np.eye(Kc_new.shape[0] * G)
+            if not self.smooth_opts['sparseGP']:
+                Z_new_mean[:,k] = gpu_utils.dot(K_new_k[newidx, :][:, oldix], gpu_utils.dot(Sigma_inv[k,:,:], Z[:,k]))
+            else:
+                U = self.model.nodes['U'].getExpectations()['E']
+                old_sub = oldix[self.model.nodes['Sigma'].idx_inducing]
+                Z_new_mean[:, k] = gpu_utils.dot(K_new_k[newidx, :][:, old_sub],
+                                                 gpu_utils.dot(Sigma_inv[k, :, :], U[:, k]))
             if uncertainty:
                 # marginal variances p(z, z*|c, c*, y) =  p(z*|z, y,c,c*) *p(z|y,c,c*)  = p(z*|z, c*) * p(z|y,c)
                 # Var[z*] = Var([E(z*|z)]) + Var(E(z*|z))
                 # if not self.model_opts['mv_Znode']:
                 #     Z2 = np.diag(self.model.nodes['Z'].getExpectations()['E2'][:,k] - self.model.nodes['Z'].getExpectations()['E'][:,k]**2)
-                # else:
-                Z2 = self.model.nodes['Z'].getExpectations()['cov'][k,:,:]
                 # TODO: avoid calculating full matrix, only require diagonal
-                Z_new_var[:, k] = np.diag(Sigma_new_k[newidx, :][:, newidx] - \
-                                          gpu_utils.dot(K_new_k[newidx, :][:, oldix],
-                                                        gpu_utils.dot(Sigma_inv[k, :, :],
-                                                                      K_new_k[oldix, :][:, newidx])) + \
-                                                            gpu_utils.dot(K_new_k[newidx, :][:, oldix], gpu_utils.dot(Sigma_inv[k, :, :],
-                                                                           gpu_utils.dot(Z2,gpu_utils.dot(Sigma_inv[k, :, :],K_new_k[oldix,:][:,newidx])))))
+                if not self.smooth_opts['sparseGP']:
+                    Z2 = self.model.nodes['Z'].getExpectations()['cov'][k,:,:] #A_k
+                    Z_new_var[:, k] = np.diag(Sigma_new_k[newidx, :][:, newidx] - \
+                                              gpu_utils.dot(K_new_k[newidx, :][:, oldix],
+                                                            gpu_utils.dot(Sigma_inv[k, :, :],
+                                                                          K_new_k[oldix, :][:, newidx])) + \
+                                              gpu_utils.dot(K_new_k[newidx, :][:, oldix],
+                                                            gpu_utils.dot(Sigma_inv[k, :, :],
+                                                                          gpu_utils.dot(Z2, gpu_utils.dot(
+                                                                              Sigma_inv[k, :, :],
+                                                                              K_new_k[oldix, :][:, newidx])))))
+                else:
+                    Z2 = self.model.nodes['U'].getExpectations()['cov'][k,:,:]
+                    Z_new_var[:, k] = np.diag(Sigma_new_k[newidx, :][:, newidx] - \
+                                              gpu_utils.dot(K_new_k[newidx, :][:, old_sub],
+                                                            gpu_utils.dot(Sigma_inv[k, :, :],
+                                                                          K_new_k[old_sub, :][:, newidx])) + \
+                                              gpu_utils.dot(K_new_k[newidx, :][:, old_sub],
+                                                            gpu_utils.dot(Sigma_inv[k, :, :],
+                                                                          gpu_utils.dot(Z2, gpu_utils.dot(
+                                                                              Sigma_inv[k, :, :],
+                                                                              K_new_k[old_sub, :][:, newidx])))))
+
 
         if uncertainty:
             assert np.all(Z_new_var >= 0), "Something went wrong in the prediction: variances of the predictive distribution are negative"
